[![PyPI version](https://badge.fury.io/py/caplena.svg)](https://badge.fury.io/py/caplena)
[![Downloads](https://static.pepy.tech/personalized-badge/caplena?period=month&units=international_system&left_color=black&right_color=brightgreen&left_text=downloads/month)](https://pepy.tech/project/caplena)

# Caplena Python Library

The Caplena Python library provides convenient access to the Caplena REST API from applications written in the Python programming language.
